==> atrium-2.10.0.tar.gz: atrium-2.10.0/atrium/models/merchants_response_body.py <==
# coding: utf-8

"""
    MX API

    The MX Atrium API supports over 48,000 data connections to thousands of financial institutions. It provides secure access to your users' accounts and transactions with industry-leading cleansing, categorization, and classification.  Atrium is designed according to resource-oriented REST architecture and responds with JSON bodies and HTTP response codes.  Use Atrium's development environment, vestibule.mx.com, to quickly get up and running. The development environment limits are 100 users, 25 members per user, and access to the top 15 institutions. Contact MX to purchase production access.   # noqa: E501
"""


import pprint
import re  # noqa: F401

import six

from atrium.models.merchant import Merchant  # noqa: F401,E501
from atrium.models.pagination import Pagination  # noqa: F401,E501


class MerchantsResponseBody(object):


    """
    Attributes:
      mx_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    mx_types = {
        'merchant': 'list[Merchant]',
        'pagination': 'Pagination'
    }

    attribute_map = {
        'merchant': 'merchant',
        'pagination': 'pagination'
    }

    def __init__(self, merchant=None, pagination=None):  # noqa: E501

        self._merchant = None
        self._pagination = None
        self.discriminator = None

        if merchant is not None:
            self.merchant = merchant
        if pagination is not None:
            self.pagination = pagination

    @property
    def merchant(self):
        """Gets the merchant of this MerchantsResponseBody.  # noqa: E501


        :return: The merchant of this MerchantsResponseBody.  # noqa: E501
        :rtype: list[Merchant]
        """
        return self._merchant

    @merchant.setter
    def merchant(self, merchant):
        """Sets the merchant of this MerchantsResponseBody.


        :param merchant: The merchant of this MerchantsResponseBody.  # noqa: E501
        :type: list[Merchant]
        """

        self._merchant = merchant

    @property
    def pagination(self):
        """Gets the pagination of this MerchantsResponseBody.  # noqa: E501


        :return: The pagination of this MerchantsResponseBody.  # noqa: E501
        :rtype: Pagination
        """
        return self._pagination

    @pagination.setter
    def pagination(self, pagination):
        """Sets the pagination of this MerchantsResponseBody.


        :param pagination: The pagination of this MerchantsResponseBody.  # noqa: E501
        :type: Pagination
        """

        self._pagination = pagination

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.mx_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MerchantsResponseBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MerchantsResponseBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> atrium-2.11.5.tar.gz: atrium-2.11.5/atrium/models/merchants_response_body.py <==
# coding: utf-8

"""
    MX API

    The MX Atrium API supports over 48,000 data connections to thousands of financial institutions. It provides secure access to your users' accounts and transactions with industry-leading cleansing, categorization, and classification.  Atrium is designed according to resource-oriented REST architecture and responds with JSON bodies and HTTP response codes.  Use Atrium's development environment, vestibule.mx.com, to quickly get up and running. The development environment limits are 100 users, 25 members per user, and access to the top 15 institutions. Contact MX to purchase production access.   # noqa: E501
"""


import pprint
import re  # noqa: F401

import six

from atrium.models.merchant import Merchant  # noqa: F401,E501
from atrium.models.pagination import Pagination  # noqa: F401,E501


class MerchantsResponseBody(object):


    """
    Attributes:
      mx_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    mx_types = {
        'merchants': 'list[Merchant]',
        'pagination': 'Pagination'
    }

    attribute_map = {
        'merchants': 'merchants',
        'pagination': 'pagination'
    }

    def __init__(self, merchants=None, pagination=None):  # noqa: E501

        self._merchants = None
        self._pagination = None
        self.discriminator = None

        if merchants is not None:
            self.merchants = merchants
        if pagination is not None:
            self.pagination = pagination

    @property
    def merchants(self):
        """Gets the merchants of this MerchantsResponseBody.  # noqa: E501


        :return: The merchants of this MerchantsResponseBody.  # noqa: E501
        :rtype: list[Merchant]
        """
        return self._merchants

    @merchants.setter
    def merchants(self, merchants):
        """Sets the merchants of this MerchantsResponseBody.


        :param merchants: The merchants of this MerchantsResponseBody.  # noqa: E501
        :type: list[Merchant]
        """

        self._merchants = merchants

    @property
    def pagination(self):
        """Gets the pagination of this MerchantsResponseBody.  # noqa: E501


        :return: The pagination of this MerchantsResponseBody.  # noqa: E501
        :rtype: Pagination
        """
        return self._pagination

    @pagination.setter
    def pagination(self, pagination):
        """Sets the pagination of this MerchantsResponseBody.


        :param pagination: The pagination of this MerchantsResponseBody.  # noqa: E501
        :type: Pagination
        """

        self._pagination = pagination

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.mx_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MerchantsResponseBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MerchantsResponseBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
